@@ -1,6 +1,6 @@
 package swat;
 
-our $VERSION = '0.1.68';
+our $VERSION = '0.1.69';
 
 use base 'Exporter'; 
 
@@ -60,7 +60,9 @@ sub make_http_request {
         my $resource = get_prop('resource');
         my $http_method = get_prop('http_method'); 
 
-        my $st = execute_with_retry("$curl_cmd '$hostname$resource' > $content_file && test -f $content_file", get_prop('try_num'));
+        $curl_cmd.=' -f'  unless ignore_http_err();
+
+        my $st = execute_with_retry("$curl_cmd -s -i -o $content_file '$hostname$resource' && test -f $content_file", get_prop('try_num'));
 
         if ($st) {
             ok(1, "$http_method $hostname$resource succeeded");
@@ -662,13 +664,39 @@ For example:
 
 =item *
 
-C<ignore_http_err> - do not consider curl unsuccessful exit code as error, default value is `1`( consider ).
+C<ignore_http_err> - run curl with or without `-f' flag
+
+=over
+
+=item *
+
+swat runs curl command and then checks exit code returned
+
+
+=item *
+
+if not successful exit code returns a proper swat assert fails
+
+
+=item *
+
+by default ignore_http_err is set to 0 which make curl run with `-f' flag, for not successful http responses ( bad http status code )
+  this means error on swat side ( see previous point )
+
+
+=item *
+
+settings ignore_http_err to `1' make curl run curl without `-f' flag which result in even non successful http responses are not treated as errors 
+( a proper swat assert does not fail )
+
+
+=back
 
 
 
 =item *
 
-C<prove_options> - prove options to be passed to prove runner,  default value is `-v`. See [Prove settings]("#prove-settings") section.
+C<prove_options> - prove options to be passed to prove runner,  default value is `-v`. See [Prove settings](#prove-settings) section.
 
 
 
